@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 
 #include "gdkcairo.h"
@@ -53,7 +53,7 @@ struct _GdkGCPrivate
 
 #define GDK_GC_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GDK_TYPE_GC, GdkGCPrivate))
 
-G_DEFINE_TYPE (GdkGC, gdk_gc, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GdkGC, gdk_gc, G_TYPE_OBJECT)
 
 static void
 gdk_gc_class_init (GdkGCClass *class)
@@ -188,6 +188,10 @@ gdk_gc_finalize (GObject *object)
     gdk_region_destroy (priv->clip_region);
   if (gc->colormap)
     g_object_unref (gc->colormap);
+  if (priv->tile)
+    g_object_unref (priv->tile);
+  if (priv->stipple)
+    g_object_unref (priv->stipple);
 
   G_OBJECT_CLASS (gdk_gc_parent_class)->finalize (object);
 }
@@ -275,7 +279,6 @@ gdk_gc_set_values (GdkGC           *gc,
     gc->ts_y_origin = values->ts_y_origin;
   if (values_mask & GDK_GC_CLIP_MASK)
     {
-      GdkGCPrivate *priv = GDK_GC_GET_PRIVATE (gc);
       if (priv->clip_region)
 	{
 	  gdk_region_destroy (priv->clip_region);
@@ -563,8 +566,8 @@ _gdk_gc_set_clip_region_internal (GdkGC     *gc,
  * origin. (See gdk_gc_set_clip_origin()).
  **/
 void
-gdk_gc_set_clip_rectangle (GdkGC	*gc,
-			   GdkRectangle *rectangle)
+gdk_gc_set_clip_rectangle (GdkGC              *gc,
+			   const GdkRectangle *rectangle)
 {
   GdkRegion *region;
   
@@ -588,15 +591,19 @@ gdk_gc_set_clip_rectangle (GdkGC	*gc,
  * gdk_gc_set_clip_origin()).
  **/
 void
-gdk_gc_set_clip_region (GdkGC	  *gc,
-			GdkRegion *region)
+gdk_gc_set_clip_region (GdkGC           *gc,
+			const GdkRegion *region)
 {
+  GdkRegion *copy;
+
   g_return_if_fail (GDK_IS_GC (gc));
 
   if (region)
-    region = gdk_region_copy (region);
-  
-  _gdk_gc_set_clip_region_internal (gc, region);
+    copy = gdk_region_copy (region);
+  else
+    copy = NULL;
+
+  _gdk_gc_set_clip_region_internal (gc, copy);
 }
 
 /**
@@ -1081,7 +1088,7 @@ gc_get_foreground (GdkGC    *gc,
   if (gc->colormap)
     gdk_colormap_query_color (gc->colormap, priv->fg_pixel, color);
   else
-    g_warning ("No colormap in gc_get_background");
+    g_warning ("No colormap in gc_get_foreground");
 }
 
 static void
@@ -1108,16 +1115,19 @@ gc_get_background (GdkGC    *gc,
  *   stipple from the GC. If this is present and the fill mode
  *   of the GC isn't %GDK_STIPPLED or %GDK_OPAQUE_STIPPLED
  *   the fill mode will be forced to %GDK_STIPPLED
+ * @gc_changed: pass %FALSE if the @gc has not changed since the
+ *     last call to this function
  * 
  * Set the attributes of a cairo context to match those of a #GdkGC
  * as far as possible. Some aspects of a #GdkGC, such as clip masks
  * and functions other than %GDK_COPY are not currently handled.
  **/
 void
-_gdk_gc_update_context (GdkGC     *gc,
-			cairo_t   *cr,
-			GdkColor  *override_foreground,
-			GdkBitmap *override_stipple)
+_gdk_gc_update_context (GdkGC          *gc,
+                        cairo_t        *cr,
+                        const GdkColor *override_foreground,
+                        GdkBitmap      *override_stipple,
+                        gboolean        gc_changed)
 {
   GdkGCPrivate *priv;
   GdkFill fill;
@@ -1145,12 +1155,8 @@ _gdk_gc_update_context (GdkGC     *gc,
     }
 
   if (fill == GDK_OPAQUE_STIPPLED)
-    {
-      if (override_foreground)
-	foreground = *override_foreground;
-      else
-	gc_get_background (gc, &background);
-    }
+    gc_get_background (gc, &background);
+
 
   switch (fill)
     {
@@ -1222,6 +1228,9 @@ _gdk_gc_update_context (GdkGC     *gc,
       cairo_pattern_destroy (pattern);
     }
 
+  if (!gc_changed)
+    return;
+
   cairo_reset_clip (cr);
   if (priv->clip_region)
     {
@@ -1239,5 +1248,6 @@ _gdk_gc_update_context (GdkGC     *gc,
     }
 }
 
+
 #define __GDK_GC_C__
 #include "gdkaliasdef.c"
