@@ -24,6 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include "config.h"
 #include <stdlib.h>
 #include <sys/types.h>
 
@@ -31,6 +32,7 @@
 #include "gdkimage.h"
 #include "gdkprivate.h"
 #include "gdkinternals.h"	/* For scratch_image code */
+#include "gdkalias.h"
 
 /**
  * gdk_image_ref:
@@ -215,7 +217,7 @@ allocate_scratch_images (GdkScratchImageInfo *info,
 	  gint j;
 	  
 	  for (j = 0; j < i; j++)
-	    g_object_unref (info->static_image[i]);
+	    g_object_unref (info->static_image[j]);
 	  
 	  return FALSE;
 	}
@@ -224,6 +226,25 @@ allocate_scratch_images (GdkScratchImageInfo *info,
   return TRUE;
 }
 
+static void
+scratch_image_info_display_closed (GdkDisplay          *display,
+                                   gboolean             is_error,
+                                   GdkScratchImageInfo *image_info)
+{
+  gint i;
+
+  g_signal_handlers_disconnect_by_func (display,
+                                        scratch_image_info_display_closed,
+                                        image_info);
+
+  scratch_image_infos = g_slist_remove (scratch_image_infos, image_info);
+
+  for (i = 0; i < image_info->n_images; i++)
+    g_object_unref (image_info->static_image[i]);
+
+  g_free (image_info);
+}
+
 static GdkScratchImageInfo *
 scratch_image_info_for_depth (GdkScreen *screen,
 			      gint       depth)
@@ -247,7 +268,11 @@ scratch_image_info_for_depth (GdkScreen *screen,
   image_info->depth = depth;
   image_info->screen = screen;
 
-    /* Try to allocate as few possible shared images */
+  g_signal_connect (gdk_screen_get_display (screen), "closed",
+                    G_CALLBACK (scratch_image_info_display_closed),
+                    image_info);
+
+  /* Try to allocate as few possible shared images */
   for (i=0; i < G_N_ELEMENTS (possible_n_images); i++)
     {
       if (allocate_scratch_images (image_info, possible_n_images[i], TRUE))
@@ -421,3 +446,6 @@ gdk_image_new (GdkImageType  type,
   return _gdk_image_new_for_depth (gdk_visual_get_screen (visual), type,
 				   visual, width, height, -1);
 }
+
+#define __GDK_IMAGE_C__
+#include "gdkaliasdef.c"
