@@ -64,14 +64,8 @@
   if (!(private->event_mask & GDK_EXPOSURE_MASK))
     return;
 
-  /* For some reason, we occasionally get draw requests for zero sized rects
-   * at 0,0, just ignore those.
-   */
-  if (rect.origin.x == 0 && rect.origin.y == 0 &&
-      rect.size.width == 0 && rect.size.height == 0)
-    {
-      return;
-    }
+  if (NSEqualRects (rect, NSZeroRect))
+    return;
 
   GDK_QUARTZ_ALLOC_POOL;
 
@@ -116,15 +110,20 @@
 
   gdk_region_destroy (region);
 
-  /* Invalidate the window shadow for non-opaque views that have shadow
-   * enabled, otherwise the shadow doesn't get updated to what we draw.
-   */
-  if (![self isOpaque] && [[self window] hasShadow])
-    [[self window] invalidateShadow];
+  if (needsInvalidateShadow)
+    {
+      [[self window] invalidateShadow];
+      needsInvalidateShadow = NO;
+    }
 
   GDK_QUARTZ_RELEASE_POOL;
 }
 
+-(void)setNeedsInvalidateShadow:(BOOL)invalidate
+{
+  needsInvalidateShadow = invalidate;
+}
+
 /* For information on setting up tracking rects properly, see here:
  * http://developer.apple.com/documentation/Cocoa/Conceptual/EventOverview/EventOverview.pdf
  */
@@ -174,7 +173,9 @@
 -(void)setFrame:(NSRect)frame
 {
   [super setFrame:frame];
-  [self updateTrackingRect];
+
+  if ([self window])
+    [self updateTrackingRect];
 }
 
 @end
