@@ -292,8 +292,11 @@ _gdk_win32_window_procedure (HWND   hwnd,
   retval = inner_window_procedure (hwnd, message, wparam, lparam);
   debug_indent -= 2;
 
-  GDK_NOTE (EVENTS, g_print (" => %ld%s",
-			     retval, (debug_indent == 0 ? "\n" : "")));
+#ifdef _WIN64
+  GDK_NOTE (EVENTS, g_print (" => %I64d%s", retval, (debug_indent == 0 ? "\n" : "")));
+#else
+  GDK_NOTE (EVENTS, g_print (" => %ld%s", retval, (debug_indent == 0 ? "\n" : "")));
+#endif
 
   return retval;
 }
@@ -1301,7 +1304,14 @@ show_window_recurse (GdkWindow *window, gboolean hide_window)
 	    {
 	      if (GDK_WINDOW_OBJECT (window)->state & GDK_WINDOW_STATE_ICONIFIED)
 		{
-		  ShowWindow (GDK_WINDOW_HWND (window), SW_RESTORE);
+		  if (GDK_WINDOW_OBJECT (window)->state & GDK_WINDOW_STATE_MAXIMIZED)
+		    {
+		      ShowWindow (GDK_WINDOW_HWND (window), SW_SHOWMAXIMIZED);
+		    }
+		  else
+		    {
+		      ShowWindow (GDK_WINDOW_HWND (window), SW_RESTORE);
+		    }
 		}
 	    }
 	  else
@@ -1315,7 +1325,7 @@ show_window_recurse (GdkWindow *window, gboolean hide_window)
 }
 
 static void
-show_window_internal (GdkWindow *window, gboolean hide_window)
+do_show_window (GdkWindow *window, gboolean hide_window)
 {
   GdkWindow *tmp_window = NULL;
   GdkWindowImplWin32 *tmp_impl = GDK_WINDOW_IMPL_WIN32 (GDK_WINDOW_OBJECT (window)->impl);
@@ -1336,7 +1346,10 @@ show_window_internal (GdkWindow *window, gboolean hide_window)
 	}
 
       /* Recursively show/hide every window in the chain. */
-      show_window_recurse (tmp_window, hide_window);
+      if (tmp_window != window)
+	{
+	  show_window_recurse (tmp_window, hide_window);
+	}
     }
 }
 
@@ -1770,10 +1783,6 @@ doesnt_want_key (gint mask,
 {
   GdkWindow *modal_current = _gdk_modal_current ();
   GdkWindow *window = (GdkWindow *) gdk_win32_handle_table_lookup ((GdkNativeWindow)msg->hwnd);
-  gboolean modally_blocked = modal_current != NULL ? gdk_window_get_toplevel (window) != modal_current : FALSE;
-
-  if (modally_blocked == TRUE)
-    return TRUE;
 
   return (((msg->message == WM_KEYUP || msg->message == WM_SYSKEYUP) &&
 	   !(mask & GDK_KEY_RELEASE_MASK)) ||
@@ -2033,7 +2042,7 @@ handle_stuff_while_moving_or_resizing (void)
 static VOID CALLBACK
 modal_timer_proc (HWND     hwnd,
 		  UINT     msg,
-		  UINT     id,
+		  UINT_PTR id,
 		  DWORD    time)
 {
   if (_sizemove_in_progress)
@@ -2041,10 +2050,10 @@ modal_timer_proc (HWND     hwnd,
 }
 
 static VOID CALLBACK
-sync_timer_proc (HWND hwnd,
-		 UINT msg,
-		 UINT id,
-		 DWORD time)
+sync_timer_proc (HWND     hwnd,
+		 UINT     msg,
+		 UINT_PTR id,
+		 DWORD    time)
 {
   MSG message;
   if (PeekMessageW (&message, hwnd, WM_PAINT, WM_PAINT, PM_REMOVE))
@@ -2151,7 +2160,7 @@ gdk_event_translate (MSG  *msg,
       /* XXX Handle WM_QUIT here ? */
       if (msg->message == WM_QUIT)
 	{
-	  GDK_NOTE (EVENTS, g_print (" %d", msg->wParam));
+	  GDK_NOTE (EVENTS, g_print (" %d", (int) msg->wParam));
 	  exit (msg->wParam);
 	}
       else if (msg->message == WM_MOVE ||
@@ -2265,9 +2274,9 @@ gdk_event_translate (MSG  *msg,
       _gdk_input_codepage = atoi (buf);
       _gdk_keymap_serial++;
       GDK_NOTE (EVENTS,
-		g_print (" cs:%lu hkl:%lx%s cp:%d",
+		g_print (" cs:%lu hkl:%p%s cp:%d",
 			 (gulong) msg->wParam,
-			 msg->lParam, _gdk_input_locale_is_ime ? " (IME)" : "",
+			 (gpointer) msg->lParam, _gdk_input_locale_is_ime ? " (IME)" : "",
 			 _gdk_input_codepage));
       break;
 
@@ -2276,7 +2285,7 @@ gdk_event_translate (MSG  *msg,
       GDK_NOTE (EVENTS,
 		g_print (" %s ch:%.02x %s",
 			 _gdk_win32_key_to_string (msg->lParam),
-			 msg->wParam,
+			 (int) msg->wParam,
 			 decode_key_lparam (msg->lParam)));
 
       /* If posted without us having keyboard focus, ignore */
@@ -2301,7 +2310,7 @@ gdk_event_translate (MSG  *msg,
       GDK_NOTE (EVENTS, 
 		g_print (" %s ch:%.02x %s",
 			 _gdk_win32_key_to_string (msg->lParam),
-			 msg->wParam,
+			 (int) msg->wParam,
 			 decode_key_lparam (msg->lParam)));
 
     keyup_or_down:
@@ -2408,7 +2417,7 @@ gdk_event_translate (MSG  *msg,
        * WM_IME_CHAR might work on NT4 or Win9x with ActiveIMM, but
        * use WM_IME_COMPOSITION there, too, to simplify the code.
        */
-      GDK_NOTE (EVENTS, g_print (" %#lx", msg->lParam));
+      GDK_NOTE (EVENTS, g_print (" %#lx", (long) msg->lParam));
 
       if (!(msg->lParam & GCS_RESULTSTR))
 	break;
@@ -2590,8 +2599,8 @@ gdk_event_translate (MSG  *msg,
 
     case WM_MOUSEMOVE:
       GDK_NOTE (EVENTS,
-		g_print (" %#x (%d,%d)",
-			 msg->wParam,
+		g_print (" %p (%d,%d)",
+			 (gpointer) msg->wParam,
 			 GET_X_LPARAM (msg->lParam), GET_Y_LPARAM (msg->lParam)));
 
       /* If we haven't moved, don't create any GDK event. Windows
@@ -2877,7 +2886,7 @@ gdk_event_translate (MSG  *msg,
       break;
 
     case WM_SHOWWINDOW:
-      GDK_NOTE (EVENTS, g_print (" %d", msg->wParam));
+      GDK_NOTE (EVENTS, g_print (" %d", (int) msg->wParam));
 
       if (!(((GdkWindowObject *) window)->event_mask & GDK_STRUCTURE_MASK))
 	break;
@@ -2923,7 +2932,7 @@ gdk_event_translate (MSG  *msg,
 	{
 	case SC_MINIMIZE:
 	case SC_RESTORE:
-	  show_window_internal (window, msg->wParam == SC_MINIMIZE ? TRUE : FALSE);
+	  do_show_window (window, msg->wParam == SC_MINIMIZE ? TRUE : FALSE);
 	  break;
 	}
 
@@ -2952,7 +2961,7 @@ gdk_event_translate (MSG  *msg,
 	  gdk_synthesize_window_state (window,
 				       GDK_WINDOW_STATE_WITHDRAWN,
 				       GDK_WINDOW_STATE_ICONIFIED);
-	  show_window_internal (window, TRUE);
+	  do_show_window (window, TRUE);
 	}
       else if ((msg->wParam == SIZE_RESTORED ||
 		msg->wParam == SIZE_MAXIMIZED) &&
@@ -2974,7 +2983,7 @@ gdk_event_translate (MSG  *msg,
 
 	      if (GDK_WINDOW_TYPE (window) != GDK_WINDOW_TEMP && !GDK_WINDOW_IS_MAPPED (window))
 		{
-		  show_window_internal (window, FALSE);
+		  do_show_window (window, FALSE);
 		}
 	    }
 	  else if (msg->wParam == SIZE_MAXIMIZED)
@@ -3410,7 +3419,7 @@ gdk_event_translate (MSG  *msg,
 	  event->selection.selection = GDK_SELECTION_CLIPBOARD;
 	  event->selection.target = target;
 	  event->selection.property = _gdk_selection_property;
-	  event->selection.requestor = (guint32) msg->hwnd;
+	  event->selection.requestor = msg->hwnd;
 	  event->selection.time = msg->time;
 
 	  fixup_event (event);
@@ -3476,18 +3485,18 @@ gdk_event_translate (MSG  *msg,
        * constants as case labels.
        */
     case WT_PACKET:
-      GDK_NOTE (EVENTS, g_print (" %d %#lx",
-				 msg->wParam, msg->lParam));
+      GDK_NOTE (EVENTS, g_print (" %d %p",
+				 (int) msg->wParam, (gpointer) msg->lParam));
       goto wintab;
       
     case WT_CSRCHANGE:
-      GDK_NOTE (EVENTS, g_print (" %d %#lx",
-				 msg->wParam, msg->lParam));
+      GDK_NOTE (EVENTS, g_print (" %d %p",
+				 (int) msg->wParam, (gpointer) msg->lParam));
       goto wintab;
       
     case WT_PROXIMITY:
-      GDK_NOTE (EVENTS, g_print (" %#x %d %d",
-				 msg->wParam,
+      GDK_NOTE (EVENTS, g_print (" %p %d %d",
+				 (gpointer) msg->wParam,
 				 LOWORD (msg->lParam),
 				 HIWORD (msg->lParam)));
       /* Fall through */
