@@ -27,18 +27,28 @@
 #include "gtkmodules.h"
 #include "gtkprivate.h"
 #include "gtkprintbackend.h"
+#include "gtkprinter-private.h"
 #include "gtkalias.h"
 
 #define GTK_PRINT_BACKEND_GET_PRIVATE(o)  \
    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_PRINT_BACKEND, GtkPrintBackendPrivate))
 
-static void gtk_print_backend_dispose (GObject *object);
+static void gtk_print_backend_dispose      (GObject      *object);
+static void gtk_print_backend_set_property (GObject      *object,
+                                            guint         prop_id,
+                                            const GValue *value,
+                                            GParamSpec   *pspec);
+static void gtk_print_backend_get_property (GObject      *object,
+                                            guint         prop_id,
+                                            GValue       *value,
+                                            GParamSpec   *pspec);
 
 struct _GtkPrintBackendPrivate
 {
   GHashTable *printers;
   guint printer_list_requested : 1;
   guint printer_list_done : 1;
+  GtkPrintBackendStatus status;
 };
 
 enum {
@@ -52,6 +62,12 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+enum 
+{ 
+  PROP_ZERO,
+  PROP_STATUS
+};
+
 static GObjectClass *backend_parent_class;
 
 GQuark
@@ -125,7 +141,7 @@ gtk_print_backend_module_load (GTypeModule *module)
   pb_module->exit = exitp;
   pb_module->create = createp;
 
-  /* call the filesystems's init function to let it */
+  /* call the printbackend's init function to let it */
   /* setup anything it needs to set up. */
   pb_module->init (module);
 
@@ -172,6 +188,50 @@ _gtk_print_backend_module_class_init (GtkPrintBackendModuleClass *class)
   gobject_class->finalize = gtk_print_backend_module_finalize;
 }
 
+static void 
+gtk_print_backend_set_property (GObject      *object,
+                                guint         prop_id,
+                                const GValue *value,
+                                GParamSpec   *pspec)
+{
+  GtkPrintBackend *backend = GTK_PRINT_BACKEND (object);
+  GtkPrintBackendPrivate *priv;
+
+  priv = backend->priv = GTK_PRINT_BACKEND_GET_PRIVATE (backend); 
+
+  switch (prop_id)
+    {
+    case PROP_STATUS:
+      priv->status = g_value_get_int (value);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void 
+gtk_print_backend_get_property (GObject    *object,
+                                guint       prop_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
+{
+  GtkPrintBackend *backend = GTK_PRINT_BACKEND (object);
+  GtkPrintBackendPrivate *priv;
+
+  priv = backend->priv = GTK_PRINT_BACKEND_GET_PRIVATE (backend); 
+
+  switch (prop_id)
+    {
+    case PROP_STATUS:
+      g_value_set_int (value, priv->status);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
 static void
 _gtk_print_backend_module_init (GtkPrintBackendModule *pb_module)
 {
@@ -192,11 +252,11 @@ _gtk_print_backend_module_create (GtkPrintBackendModule *pb_module)
 }
 
 static GtkPrintBackend *
-_gtk_print_backend_create (const char *backend_name)
+_gtk_print_backend_create (const gchar *backend_name)
 {
   GSList *l;
-  char *module_path;
-  char *full_name;
+  gchar *module_path;
+  gchar *full_name;
   GtkPrintBackendModule *pb_module;
   GtkPrintBackend *pb;
 
@@ -228,8 +288,9 @@ _gtk_print_backend_create (const char *backend_name)
 	  pb = _gtk_print_backend_module_create (pb_module);
 
 	  /* Increase use-count so that we don't unload print backends.
-	     There is a problem with module unloading in the cups module,
-	     see cups_dispatch_watch_finalize for details. */
+	   * There is a problem with module unloading in the cups module,
+	   * see cups_dispatch_watch_finalize for details. 
+	   */
 	  g_type_module_use (G_TYPE_MODULE (pb_module));
 	}
       
@@ -237,36 +298,10 @@ _gtk_print_backend_create (const char *backend_name)
     }
 
   return pb;
-
-  return NULL;
 }
 
-static void
-gtk_print_backend_initialize (void)
-{
-  static gboolean initialized = FALSE;
-
-  if (!initialized)
-    {
-      gtk_settings_install_property (g_param_spec_string ("gtk-print-backends",
-							  P_("Default print backend"),
-							  P_("List of the GtkPrintBackend backends to use by default"),
-							  GTK_PRINT_BACKENDS,
-							  GTK_PARAM_READWRITE));
-
-      gtk_settings_install_property (g_param_spec_string ("gtk-print-preview-command",
-							  P_("Default command to run when displaying a print preview"),
-							  P_("Command to run when displaying a print preview"),
-							  GTK_PRINT_PREVIEW_COMMAND,
-							  GTK_PARAM_READWRITE)); 
-      initialized = TRUE;
-    }
-}
-
-
-
 GList *
-gtk_print_backend_load_modules ()
+gtk_print_backend_load_modules (void)
 {
   GList *result;
   GtkPrintBackend *backend;
@@ -277,11 +312,11 @@ gtk_print_backend_load_modules ()
 
   result = NULL;
 
-  gtk_print_backend_initialize ();
-  
   settings = gtk_settings_get_default ();
-
-  g_object_get (settings, "gtk-print-backends", &setting, NULL);
+  if (settings)
+    g_object_get (settings, "gtk-print-backends", &setting, NULL);
+  else
+    setting = g_strdup (GTK_PRINT_BACKENDS);
 
   backends = g_strsplit (setting, ",", -1);
 
@@ -307,16 +342,17 @@ gtk_print_backend_load_modules ()
 
 G_DEFINE_TYPE (GtkPrintBackend, gtk_print_backend, G_TYPE_OBJECT)
 
-static void                 fallback_printer_request_details  (GtkPrinter          *printer);
-static gboolean             fallback_printer_mark_conflicts   (GtkPrinter          *printer,
-							       GtkPrinterOptionSet *options);
-static void                 fallback_printer_get_hard_margins (GtkPrinter          *printer,
-							       double              *top,
-							       double              *bottom,
-							       double              *left,
-							       double              *right);
-static GList *              fallback_printer_list_papers      (GtkPrinter          *printer);
-static GtkPrintCapabilities fallback_printer_get_capabilities (GtkPrinter          *printer);
+static void                 fallback_printer_request_details       (GtkPrinter          *printer);
+static gboolean             fallback_printer_mark_conflicts        (GtkPrinter          *printer,
+								    GtkPrinterOptionSet *options);
+static void                 fallback_printer_get_hard_margins      (GtkPrinter          *printer,
+								    gdouble             *top,
+								    gdouble             *bottom,
+								    gdouble             *left,
+								    gdouble             *right);
+static GList *              fallback_printer_list_papers           (GtkPrinter          *printer);
+static GtkPageSetup *       fallback_printer_get_default_page_size (GtkPrinter          *printer);
+static GtkPrintCapabilities fallback_printer_get_capabilities      (GtkPrinter          *printer);
   
 static void
 gtk_print_backend_class_init (GtkPrintBackendClass *class)
@@ -327,13 +363,26 @@ gtk_print_backend_class_init (GtkPrintBackendClass *class)
   backend_parent_class = g_type_class_peek_parent (class);
   
   object_class->dispose = gtk_print_backend_dispose;
+  object_class->set_property = gtk_print_backend_set_property;
+  object_class->get_property = gtk_print_backend_get_property;
 
   class->printer_request_details = fallback_printer_request_details;
   class->printer_mark_conflicts = fallback_printer_mark_conflicts;
   class->printer_get_hard_margins = fallback_printer_get_hard_margins;
   class->printer_list_papers = fallback_printer_list_papers;
+  class->printer_get_default_page_size = fallback_printer_get_default_page_size;
   class->printer_get_capabilities = fallback_printer_get_capabilities;
   
+  g_object_class_install_property (object_class, 
+                                   PROP_STATUS,
+                                   g_param_spec_int ("status",
+                                                     "Status",
+                                                     "The status of the print backend",
+                                                     GTK_PRINT_BACKEND_STATUS_UNKNOWN,
+                                                     GTK_PRINT_BACKEND_STATUS_UNAVAILABLE,
+                                                     GTK_PRINT_BACKEND_STATUS_UNKNOWN,
+                                                     GTK_PARAM_READWRITE)); 
+
   g_type_class_add_private (class, sizeof (GtkPrintBackendPrivate));
   
   signals[PRINTER_LIST_CHANGED] =
@@ -400,7 +449,8 @@ gtk_print_backend_dispose (GObject *object)
   priv = backend->priv;
 
   /* We unref the printers in dispose, not in finalize so that
-     we can break refcount cycles with gtk_print_backend_destroy */
+   * we can break refcount cycles with gtk_print_backend_destroy 
+   */
   if (priv->printers)
     {
       g_hash_table_destroy (priv->printers);
@@ -417,7 +467,7 @@ fallback_printer_request_details (GtkPrinter *printer)
 }
 
 static gboolean
-fallback_printer_mark_conflicts (GtkPrinter *printer,
+fallback_printer_mark_conflicts (GtkPrinter          *printer,
 				 GtkPrinterOptionSet *options)
 {
   return FALSE;
@@ -425,10 +475,10 @@ fallback_printer_mark_conflicts (GtkPrinter *printer,
 
 static void
 fallback_printer_get_hard_margins (GtkPrinter *printer,
-				   double *top,
-				   double *bottom,
-				   double *left,
-				   double *right)
+				   gdouble    *top,
+				   gdouble    *bottom,
+				   gdouble    *left,
+				   gdouble    *right)
 {
   *top = 0;
   *bottom = 0;
@@ -442,6 +492,12 @@ fallback_printer_list_papers (GtkPrinter *printer)
   return NULL;
 }
 
+static GtkPageSetup *
+fallback_printer_get_default_page_size (GtkPrinter *printer)
+{
+  return NULL;
+}
+
 static GtkPrintCapabilities
 fallback_printer_get_capabilities (GtkPrinter *printer)
 {
@@ -450,9 +506,9 @@ fallback_printer_get_capabilities (GtkPrinter *printer)
 
 
 static void
-printer_hash_to_sorted_active_list (const gchar *key,
-                                    gpointer value,
-                                    GList **out_list)
+printer_hash_to_sorted_active_list (const gchar  *key,
+                                    gpointer      value,
+                                    GList       **out_list)
 {
   GtkPrinter *printer;
 
@@ -470,7 +526,7 @@ printer_hash_to_sorted_active_list (const gchar *key,
 
 void
 gtk_print_backend_add_printer (GtkPrintBackend *backend,
-			       GtkPrinter *printer)
+			       GtkPrinter      *printer)
 {
   GtkPrintBackendPrivate *priv;
   
@@ -488,7 +544,7 @@ gtk_print_backend_add_printer (GtkPrintBackend *backend,
 
 void
 gtk_print_backend_remove_printer (GtkPrintBackend *backend,
-				  GtkPrinter *printer)
+				  GtkPrinter      *printer)
 {
   GtkPrintBackendPrivate *priv;
   
@@ -535,8 +591,8 @@ gtk_print_backend_get_printer_list (GtkPrintBackend *backend)
 	GTK_PRINT_BACKEND_GET_CLASS (backend)->request_printer_list (backend);
       priv->printer_list_requested = TRUE;
     }
-  
-  return result;;
+
+  return result;
 }
 
 gboolean
@@ -549,7 +605,7 @@ gtk_print_backend_printer_list_is_done (GtkPrintBackend *print_backend)
 
 GtkPrinter *
 gtk_print_backend_find_printer (GtkPrintBackend *backend,
-                                const gchar *printer_name)
+                                const gchar     *printer_name)
 {
   GtkPrintBackendPrivate *priv;
   GtkPrinter *printer;
@@ -567,18 +623,18 @@ gtk_print_backend_find_printer (GtkPrintBackend *backend,
 }
 
 void
-gtk_print_backend_print_stream (GtkPrintBackend *backend,
-                                GtkPrintJob *job,
-                                gint data_fd,
+gtk_print_backend_print_stream (GtkPrintBackend        *backend,
+                                GtkPrintJob            *job,
+                                GIOChannel             *data_io,
                                 GtkPrintJobCompleteFunc callback,
-                                gpointer user_data,
-				GDestroyNotify dnotify)
+                                gpointer                user_data,
+				GDestroyNotify          dnotify)
 {
   g_return_if_fail (GTK_IS_PRINT_BACKEND (backend));
 
   GTK_PRINT_BACKEND_GET_CLASS (backend)->print_stream (backend,
 						       job,
-						       data_fd,
+						       data_io,
 						       callback,
 						       user_data,
 						       dnotify);
@@ -588,13 +644,14 @@ void
 gtk_print_backend_destroy (GtkPrintBackend *print_backend)
 {
   /* The lifecycle of print backends and printers are tied, such that
-     the backend owns the printers, but the printers also ref the backend.
-     This is so that if the app has a reference to a printer its backend
-     will be around. However, this results in a cycle, which we break
-     with this call, which causes the print backend to release its printers.
-  */
+   * the backend owns the printers, but the printers also ref the backend.
+   * This is so that if the app has a reference to a printer its backend
+   * will be around. However, this results in a cycle, which we break
+   * with this call, which causes the print backend to release its printers.
+   */
   g_object_run_dispose (G_OBJECT (print_backend));
 }
 
+
 #define __GTK_PRINT_BACKEND_C__
 #include "gtkaliasdef.c"
